@@ -10,16 +10,6 @@ module System.PosixCompat.Internal.Time (
     ) where
 
 import System.Posix.Types (EpochTime)
-
-#ifdef OLD_TIME
-
-import System.Time (ClockTime(TOD), getClockTime)
-
-clockTimeToEpochTime :: ClockTime -> EpochTime
-clockTimeToEpochTime (TOD s _) = fromInteger s
-
-#else
-
 import Data.Time.Clock.POSIX (POSIXTime, getPOSIXTime)
 
 type ClockTime = POSIXTime
@@ -29,5 +19,3 @@ getClockTime = getPOSIXTime
 
 clockTimeToEpochTime :: ClockTime -> EpochTime
 clockTimeToEpochTime = fromInteger . floor
-
-#endif
